@@ -142,7 +142,7 @@ class PortfolioBar(NamedTuple):
 
     Attributes:
         date: Date of bar.
-        cash: Amount of cash in :class:`.Portfolio` .
+        cash: Amount of cash in :class:`.Portfolio`.
         equity: Amount of equity in :class:`.Portfolio`.
         margin: Amount of margin in :class:`.Portfolio`.
         market_value: Market value of :class:`.Portfolio`.
@@ -287,7 +287,7 @@ class Portfolio:
         if self._fee_mode is None or self._fee_amount is None:
             return fees
         if self._fee_mode == FeeMode.ORDER_PERCENT:
-            fees = self._fee_amount * fill_price * shares
+            fees = self._fee_amount / Decimal(100) * fill_price * shares
         elif self._fee_mode == FeeMode.PER_ORDER:
             fees = self._fee_amount
         elif self._fee_mode == FeeMode.PER_SHARE:
@@ -784,7 +784,7 @@ class Portfolio:
         )
 
     def incr_bars(self):
-        """Increments the number of bars held of each trade entry."""
+        """Increments the number of bars held by every trade entry."""
         for pos in self.long_positions.values():
             for entry in pos.entries:
                 entry.bars += 1
